EcsError

Enum EcsError 

pub enum EcsError {
    NotInitialized,
    AlreadyBorrowed,
    DispatcherExecutionFailed(Vec<EcsError>),
    SystemError(Box<dyn Error + Send>),
}
The types of errors a System can create.

Variants



NotInitialized

A resource was not initialized in the World but the System tries to access it.

Usually, this means no dispatcher was used and World::initialize was not called.



AlreadyBorrowed

The requested resource is already borrowed. This error is created if the System tries to read a resource that has already been mutably borrowed. It can also happen when trying to mutably borrow a resource that is already being read.

This error should not occur during normal use, as the dispatchers can recover easily.



DispatcherExecutionFailed(Vec<EcsError>)

The execution of the dispatcher failed and returned one or more errors.



SystemError(Box<dyn Error + Send>)

This variant is for user-defined errors. To create an error of this type easily, use the system_error! macro.