ItemError

Enum ItemError 

pub enum ItemError<K, U>
where K: PartialEq + Debug, U: Default,
{ StackOverflow(ItemInstance<K, U>), InventoryFull, InventoryOverflow(Vec<ItemInstance<K, U>>), ItemDestroyed(ItemInstance<K, U>), StackConsumed(ItemInstance<K, U>), SlotOccupied, SlotRestricted, LockedOriginSlot, LockedRemoteSlot, SlotEmpty, NotEnoughQuantity, }
The different errors that can happen when interacting with the Inventory.

Variants



StackOverflow(ItemInstance<K, U>)

The stack doesn’t fit completely inside of the slot.



InventoryFull

The inventory is full and cannot be resized anymore.



InventoryOverflow(Vec<ItemInstance<K, U>>)

The inventory cannot fit the specified items inside of itself. It has no more empty slots, cannot be resized and no item can be stacked with others.



ItemDestroyed(ItemInstance<K, U>)

The item was used and the durability is now 0.



StackConsumed(ItemInstance<K, U>)

The stack size was decreased and is now 0.



SlotOccupied

The slot already has something inside of it.



SlotRestricted

The specified item cannot be inserted into this type of slot.



LockedOriginSlot

The origin slot is locked. The item cannot be moved or inserted.



LockedRemoteSlot

The remote slot is locked. The item cannot be moved or inserted.



SlotEmpty

The slot at the specified index is empty or non-existant.



NotEnoughQuantity

There is not enough of the specified item to satisfy the query.