pub fn remove_outdated_effector_system<E>(
time: &Time,
effectors: &mut Components<EffectorSet<E>>,
) -> Result<(), EcsError>Expand description
Removes effectors where their time to live is expired. Note: Run after ApplyEffectorsSystem.
pub fn remove_outdated_effector_system<E>(
time: &Time,
effectors: &mut Components<EffectorSet<E>>,
) -> Result<(), EcsError>Removes effectors where their time to live is expired. Note: Run after ApplyEffectorsSystem.