pub struct Camera {
pub position: Point,
pub screen_position: Point,
pub size: Point,
}Expand description
Used to change the visible space of the world on screen.
Fields
position: PointThe position of the camera in the world.
screen_position: PointThe position of the camera on screen.
size: PointThe size in tiles that the camera can view.
Implementations