Dispatcher

Struct Dispatcher 

pub struct Dispatcher { /* private fields */ }
A dispatcher is used to execute a collection of System in order and possibly in parallel using World’s resources. A dispatcher automatically avoids mutable borrow collisions which would normally lead to data corruption, dead locks and more.

Implementations

Source

impl Dispatcher

pub fn run_seq(&mut self, world: &World) -> Result<(), EcsError>

Runs the systems one after the other, one at a time.

pub fn run_par(&mut self, world: &World) -> Result<(), EcsError>

Runs the systems in parallel. Systems having conflicts in their dependencies (the resource reference they use are the same and at least one is mutable) are run sequentially relative to each other, while systems without conflict run in parallel.