ItemInstance

Struct ItemInstance 

pub struct ItemInstance<K, U>
where U: Default,
{ pub key: K, pub quantity: usize, pub durability: Option<usize>, pub user_data: U, }
An ItemInstance is a stack of item. It refers to the ItemDefinition’s key. The associated ItemDefinition contains the data describing that object type. An item stack can be composed of one or many of the same item. It can also have a durability, which decreases when the item is used using Inventory::use_item.

Custom data can be added into the user_data field. This data is specific to each item instance.

Generic Types:

  • K: Type of the key. Usually an enum or a number (ie u32).
  • U: The type of the custom user data. If you don’t have any, use the () type. It can (and probably should) be different than the custom user data used on ItemInstances

Fields

key: K

The key specifies which ItemDefinition defines the properties of this item stack.

quantity: usize

The number of items in the stack. Should not be over the associated ItemDefinition::maximum_stack.

durability: Option<usize>

The remaining durability of this item, if any. If set to None, it means that the item is unbreakable.

user_data: U

The custom user data.

Implementations

Source

impl<K, U> ItemInstance<K, U>
where U: Default,

pub fn new(key: K, quantity: usize) -> ItemInstance<K, U>

Constructs a new ItemInstance.

Source

impl<K, U> ItemInstance<K, U>
where K: Eq + Hash, U: Default + PartialEq,

pub fn merge<S, U2>( &mut self, other: &mut ItemInstance<K, U>, item_defs: &ItemDefinitions<K, S, U2>, )
where U2: Default,

Attempts to move as much quantity from other to self as possible.