ItemTransitionDefinition

Struct ItemTransitionDefinition 

pub struct ItemTransitionDefinition<K, I, E, S> {
    pub key: K,
    pub name: String,
    pub friendly_name: String,
    pub icon_path: Option<String>,
    pub input_items: Vec<(I, usize, UseMode)>,
    pub stat_conditions: Vec<StatCondition<S>>,
    pub stat_effectors: Vec<E>,
    pub output_items: Vec<(I, usize)>,
    pub on_condition_lost: ConditionLostReaction,
    pub time_to_complete: f64,
    pub consume_input_immediate: bool,
    pub auto_trigger: bool,
}
A transition from one or more items into one or more different items. Can be used for all sorts of crafting.

Fields

key: K

The id of this item transition.

name: String

The name of the transition.

friendly_name: String

The friendly name of the transition.

icon_path: Option<String>

The icon path.

input_items: Vec<(I, usize, UseMode)>

The different input items, quantities and UseMode for each one.

stat_conditions: Vec<StatCondition<S>>

The required stats conditions required to process the transition.

stat_effectors: Vec<E>

The effectors applied during crafting.

output_items: Vec<(I, usize)>

The different output items.

on_condition_lost: ConditionLostReaction

What happens when you lose the condition required to continue the transition.

time_to_complete: f64

The time to complete the transition.

consume_input_immediate: bool

Consume the input items at the start of the transition, regardless of the result.

auto_trigger: bool

Automatically transition when all the required conditions are met.

Implementations

Source

impl<K, I, E, S> ItemTransitionDefinition<K, I, E, S>

pub fn new( key: K, name: String, friendly_name: String, icon_path: Option<String>, input_items: Vec<(I, usize, UseMode)>, stat_conditions: Vec<StatCondition<S>>, stat_effectors: Vec<E>, output_items: Vec<(I, usize)>, on_condition_lost: ConditionLostReaction, time_to_complete: f64, consume_input_immediate: bool, auto_trigger: bool, ) -> ItemTransitionDefinition<K, I, E, S>

Constructs a new ItemTransitionDefinition.