pub struct Unlockable<U, K, S, I> {
pub id: U,
pub inner: K,
pub is_unlocked: bool,
pub unlock_stat_conditions: Vec<StatCondition<S>>,
pub unlock_item_conditions: Vec<(I, usize, UseMode)>,
pub unlock_dependencies: Vec<U>,
}Expand description
An unlockable element. It can be unlocked to access the inner value if all conditions are met:
StatConditions- Item Conditions
- Dependant unlockables were previously unlocked.
Fields
id: UThe key of this unlockable.
inner: KThe thing we want to unlock access to.
is_unlocked: boolWhether we unlocked it or not.
unlock_stat_conditions: Vec<StatCondition<S>>The stat conditions required to unlock this element.
unlock_item_conditions: Vec<(I, usize, UseMode)>The item conditions required to unlock this element.
unlock_dependencies: Vec<U>A list of other unlockables upon which this one depends. If Unlockable B depends on A, then A must be unlocked before B can be unlocked.
Implementations
Sourceimpl<U, K, S, I> Unlockable<U, K, S, I>
impl<U, K, S, I> Unlockable<U, K, S, I>
Sourcepub fn new(id: U, inner: K, is_unlocked: bool) -> Unlockable<U, K, S, I>
pub fn new(id: U, inner: K, is_unlocked: bool) -> Unlockable<U, K, S, I>
Constructs a new Unlockable.
Sourceimpl<U, K, S, I> Unlockable<U, K, S, I>
impl<U, K, S, I> Unlockable<U, K, S, I>
Sourcepub fn try_get(&self) -> Option<&K>
pub fn try_get(&self) -> Option<&K>
Returns Some with the inner value if is_unlocked = true. Otherwise returns None
Sourcepub fn try_get_mut(&mut self) -> Option<&mut K>
pub fn try_get_mut(&mut self) -> Option<&mut K>
Returns Some with the inner value if is_unlocked = true. Otherwise returns None
Sourcepub fn set(&mut self, new: K)
pub fn set(&mut self, new: K)
Inserts a new value without changing the lock. Returns the previous inner value.
Sourcepub fn is_unlocked(&self) -> bool
pub fn is_unlocked(&self) -> bool
Verifies if the inner value is locked.