pub struct ItemInstance<K, U>where
U: Default,{
pub key: K,
pub quantity: usize,
pub durability: Option<usize>,
pub user_data: U,
}Expand description
An ItemInstance is a stack of item.
It refers to the ItemDefinition’s key. The associated ItemDefinition contains the data
describing that object type.
An item stack can be composed of one or many of the same item.
It can also have a durability, which decreases when the item is used using
Inventory::use_item.
Custom data can be added into the user_data field. This data is specific to each item instance.
Generic Types:
- K: Type of the key. Usually an enum or a number (ie u32).
- U: The type of the custom user data. If you don’t have any, use the
()type. It can (and probably should) be different than the custom user data used onItemInstances
Fields
key: KThe key specifies which ItemDefinition defines the properties of this item stack.
quantity: usizeThe number of items in the stack.
Should not be over the associated ItemDefinition::maximum_stack.
durability: Option<usize>The remaining durability of this item, if any. If set to None, it means that the item is unbreakable.
user_data: UThe custom user data.
Implementations
Sourceimpl<K, U> ItemInstance<K, U>where
U: Default,
impl<K, U> ItemInstance<K, U>where
U: Default,
Sourcepub fn new(key: K, quantity: usize) -> ItemInstance<K, U>
pub fn new(key: K, quantity: usize) -> ItemInstance<K, U>
Constructs a new ItemInstance.
Sourceimpl<K, U> ItemInstance<K, U>
impl<K, U> ItemInstance<K, U>
Sourcepub fn merge<S, U2>(
&mut self,
other: &mut ItemInstance<K, U>,
item_defs: &ItemDefinitions<K, S, U2>,
)where
U2: Default,
pub fn merge<S, U2>(
&mut self,
other: &mut ItemInstance<K, U>,
item_defs: &ItemDefinitions<K, S, U2>,
)where
U2: Default,
Attempts to move as much quantity from other to self as possible.